bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 19. Aventiure
___________________________________________________ #### Aventivre wie der nibelvnge hort #### ze wormze braht wart
###### 1101 | ### Do div edel criemhilt | also verwitwet wart ### bi ir ime lande | der grave ecchewart ### beleip mit sinen mannen | der dienet ir zallen tagen ### der half ovch siner vrowen | sinen herren diche chlagen
###### 1102 | ### ze wormez bi dem mvnster | ein gezimber man ir sloz ### wit vnd vil michel | rich vnd groz ### da si mit ir gesinde | sit ane vrevde saz ### si was cer chirchen gerne | vnd tet vil gvetlichen daz
###### 1103 | ### da man begrvb ir vriedel | wi selten si daz lie ### mit trvregem mvte | si alle cit dar gie ### si bat got den gvten | siner sele pflegen ### vil diche wart beweinet | mit grozzen triwen der degen
###### 1104 | ### vte vnd ir gesinde | trosten si zaller stvnt ### do was ir daz herce | so grozliche wunt ### ez chvnde niht vervahen | swaz man ir trostes bot ### si hete nach liebem vrivnde | di allergrosten not
###### 1105 | ### di nach liebem manne | ie mer wip gewan ### man mohte ir michel tvgende | chiesen wol daran ### si chlagete vnz an ir ende | di wile wert si der lip ### sit rach sich wol mit ellen | des chvenen sifrides wip
###### 1106 | ### svs saz si nach ir leide | daz ist alle war ### nach ir mannes tode | wol vierdehalbez iar ### daz si ce gvnther | nie dehein wort gesprach ### vnt ovch ir vient hagenen | in der cite nie gesach
###### 1107 | ### do sprach der helt von tronege | moht ir daz tragen an ### daz ir iwer swester | ce vrivnde mohtet han ### so chome ce disen landen | daz nibelvnges golt ### des moht ir wol gewinnen | wuerd vns div chvneginne holt
###### 1108 | ### er sprach wir svln iz versvchen | mine brvder sint ir bi ### di svl wirz piten werben | daz si vnser vrivnt si ### ob virn ir angewinnen | daz si daz gerne sehe ### ine truwes niht sprach hagene | daz daz immer geschehe
###### 1109 | ### do hiez er ortwinen | hin ce hove gan ### vnt den margraven geren | do daz was getan ### man braht ovch gernoten | vnd giselher daz chint ### si versvchtenz vrivntliche | an vrovn criemhilde sint
###### 1110 | ### prvnhilt div schoene | mit vebermvete saz ### vrowe ir chlaget ce lange | den sifrides tot ### iv wil der chvenich rihten | daz er sin niht hat erslagen ### man horet ivch zallen citen | so rehte grozlichen chlagen
###### 1111 | ### si sprach des zihet in niemen | in slvch div hagenen hant ### wa man in verhowen solde | do er daz an mir ervant ### wi moht ich des getruwen | daz er im waere gehaz ### ich hete wol behvtet | sprach div chvneginne daz
###### 1112 | ### daz ich niht vermeldet | hete sinen lip ### so lieze ich nv min weinen | ich vil armes wip ### holt wirt ich in nimmer | di ez da hant getan ### do begonde vlehen giselher | der vil waetliche man
###### 1113 | ### ich wil den chvenich grvezen | do si im des veriach ### mit sinen besten vrivnden | man in vor ir sach ### do ne torste hagen | fvr si niht gegan ### wol wesse er sine schvlde | er het ir leide getan
###### 1114 | ### do si verchiesen wolde | vf gvnthern den haz ### ob er si chvessen solde | ez zaeme im deste baz ### waere ir von sinem rate | leide niht getan ### so moeht er vnzwifellichen | zv criemhilde gan
###### 1115 | ### ez en wart nie svne | mit so vil traehen me ### gefveget vnder vrivnden | ir tet ir schade we ### si verchos vf si alle | wan vf den einem man ### in het erslagen niemen | ez hete hagen getan
###### 1116 | ### darnach vil vnlange | trvgen si daz an ### daz div vrowe criemhilt | den grozen hort gewan ### von nibelvnge lande | vnd fvrten an den rin ### er was ir morgengabe | er solt ir pilliche sin
###### 1117 | ### darnach fvr giselher | vnd gernot ### ir ahzech hvndert mannen | criemhilt do gebot ### daz sin holen solden | da er verborgen lach ### da sin der degen albrich | mit sinen besten vrivnden pflach
###### 1118 | ### do man di von dem rine | nach dem schatze chomen sach ### albrich der vil chvene | zv sinen vrivnden sprach ### wirn getverren ir des hordes | vor gehaben niht ### sit sin ce morgengabe | div edel kveneginne ihit
###### 1119 | ### doch wurdez nimmer | sprach albrich getan ### niwan daz wir vebele | da verlorn han ### mit samt sifrit | di gvten tarnhvt ### want di trvch alle cite | der schoenen criemhilde trvt
###### 1120 | ### nv ist ez sifride | leider vbel chomen ### daz vns di tarnchappen | hat der helt benomen ### vnt daz im mvse dienen | allez dize lant ### do gie der chameraere | da er di slvzzel vant
###### 1121 | ### ez stvnden vor dem berge | di criemhilde man ### vnd ovch ein teil ir mage | den shaz den hiez man dan ### tragen zv dem scheffe | an div schiffelin ### den fvrt man vf den vnden | vnz ze berge an den rin
###### 1122 | ### nv mveget ir von dem horde | wunder horen sagen ### swaz zwelf chanzwagene | meiste mohten tragen ### in vier tagen vnd nahten | von dem berge dan ### ovch mvose ir ietslicher | des tages dristvnt gan
###### 1123 | ### ez en was niht anders | wan steine vnd golt ### vnt ob man al di werlde | het davon versolt ### si ne waere niht | minner einer marche wert ### ia ne hetes schvlde | niht gar hagen gegert
###### 1124 | ### der wunhs der lach darvnder | von golde ein rvetelin ### der daz het erchvnnet | der mohte meister sin ### wol in aller werld | veber einn ietslichen man ### der albriches mage | chom vil mit gernote dan
###### 1125 | ### do si den hort behielten | in gvntheres lant ### vnd sih es div chveneginne | allererst vnderwant ### in chamer vnd in tvernen | sin wart vil getragen ### man gehorte nie daz wunder | von gvte mere gesagen
###### 1126 | ### vnd waere sin tvsent stvnde | noch alse vil gewesen ### vnd solt der herre sifrit | gesvnder sin gewesen ### bi im waere criemhilt | hende bloz bestan ### getriwer wibes chvenne | ein helt ni mer gewan
###### 1127 | ### do si den hort nv hete | do brahtes in daz lant ### vil vnchvnder rechen | ia gap der vrowen hant ### daz man so grozzer milte | mere ni gesach ### si pflach vil gvter tvgende | des man der chveneginne iach
###### 1128 | ### den armen vnt den richen | begonde si nv geben ### daz da reite hagene | ob si solde leben ### noch decheine wile | daz si so manigen man ### in ir dienst gewunne | daz ez in leide mvs ergan
###### 1129 | ### do sprach der chvenech gvnther | ir ist lip vnd gvt ### zwiv sol ich daz wenden | swaz si damit getvt ### ia derwap ich daz vil chvme | daz si mir wart so holt ### nv en rvchen war si teile | ir silber vnd ir golt
###### 1130 | ### hagen sprach ce dem chvnige | ez solde ein frvmer man ### deheinem einem wibe | niht des hordes lan ### si bringet ez mit gabe | noch vf den tach ### daz vil wol geriwen | di chvenen bvrgonden mach
###### 1131 | ### do sprach der kvnich gvnther | ich swuor ir einen eit ### daz ich ir getaete | nimmer mere leit ### vnd wil es fvrbaz hveten | si ist div swester min ### do sprach aber hagene | lat mich den schvldigen sin
###### 1132 | ### ir svmeliche eide | waren vmbehvht ### do namen si der witwen | daz creftige gvt ### hagen si der slvzzel | aller vnderwant ### daz zvrnde ir brvder gernot | do er daz rehte bevant
###### 1133 | ### do sprach der herre giselher | hagen hat getan ### vil leides miner swester | ich sold iz vnderstan ### waere er niht min mag | ez gienge im an den lip ### iteniwez weinen | tet do sifrides wip
###### 1134 | ### do sprach der herre gernot | e daz wir immer sin ### gemvet mit dem golde | wir soldenz in den rin ### allez heizen senchen | daz wer wol getan ### si gie vil chlegeliche | fver ir brvder gvnthere stan
###### 1135 | ### si sprach vil lieber brvder | dv solt gedenchen min ### beidiv libes vnd gvtes | soltv min voget sin ### do sprach er zv der vrowen | daz sol sin getan ### als wir nv chomen widere | wir haben ritens wan
###### 1136 | ### der kvenich vnd sine mage | rvmten do daz lant ### di allerbesten darvnder | di man inder vant ### niwan hagen aleine | der beleip da dvrch haz ### den er trvch criemhilde | vnt tet vlizechliche daz
###### 1137 | ### e daz der chvenich riche | waere wider chomen ### di wile hete hagene | den shaz vil genomen ### er schvtten da ce loche | allen in den rin ### er wand er sold in nizen | des en chvnde niht gesin
###### 1138 | ### di fversten chomen widere | mit in vil manich man ### criemhilt ir schaden grozzen | chlagen began ### mit meiden vnt mit vrowen | in was harte leit ### gerne waer ir giselher | aller triwen bereit
###### 1139 | ### do sprachen si gemeine | er hat vbele getan ### er ntweich der fvrsten zorne | also lange dan ### vnz er gewan ir hvlde | sie liezen in genesin ### do ne chvnde im criemhilt | nimmer viender sin gewesin
###### 1140 | ### e daz von tronege hagene | den shaz also verbarch ### do heten siz gevestent | mit eiden also starch ### daz er verholn waere | vnz ir einer mohte leben ### si ne chvnden ins selben | noch niemen ander gegeben
###### 1141 | ### mit itenuewen leiden | beswaeret was ir mvt ### vmb ir mannes ende | vnt do si ir daz gvt ### also gar genamen | do ne gestvnt ir chlage ### des libes nimmer mere | vnz an ir ivngesten tage
###### 1142 | ### nach sifrides tode | daz ist alwar ### si wonte in manigem sere | drivcehn iar ### daz si des recken todes | vergezzen chvnde niht ### si was im getriwe | des ir div meiste menige iht

<<< Übersicht <<< vorige Seite nächste Seite >>>